@@ -36,6 +36,7 @@ void classicmode(int *n)
         { G_DM, G_M_GSP1 | G_M_INSTA },
 
         { G_CTF, G_M_TEAM },
+        { G_CTF, G_M_GSP1 | G_M_TEAM },
         { G_BOMBER, G_M_TEAM },
         { G_HTF, G_M_TEAM },
         { G_KTF, G_M_GSP1 },
@@ -87,7 +88,7 @@ char *colorname(playerent *d)
     if(d->ownernum < 0)
         formatstring(cname[num])("%s \fs\f6(%d)\fr", d->name, d->clientnum);
     else
-        formatstring(cname[num])("%s \fs\f7[%d-%d]\fr", d->name, d->clientnum, d->ownernum);
+        formatstring(cname[num])("%s \fs\f7[%d-%d]\fr", m_zombie(gamemode) ? "a zombie" : d->name, d->clientnum, d->ownernum);
     return cname[num];
 }
 
@@ -864,12 +865,14 @@ void dodamage(int damage, playerent *pl, playerent *actor, int gun, int style, c
     if (pl != actor || gun == GUN_GRENADE || gun == GUN_RPG || pl->o.dist(src) > 4)
     {
         // damage indicator
-        pl->damagestack.add(damageinfo(src, totalmillis, damage));
+        if (pl == focus) pl->damagelist_hud.add(damageinfo(src, totalmillis, damage));
         // push
         vec dir = pl->o;
         dir.sub(src).normalize();
         pl->hitpush(damage, dir, actor, gun);
     }
+    // damage particles
+    pl->adddamage_world(totalmillis, damage, pl == focus || actor == focus);
 
     // critical damage
     if(style & FRAG_CRIT)
@@ -1317,13 +1320,13 @@ void flagmsg(int flag, int message, int actor, int flagtime)
                 hudoutf("\f2you %s %s flag", droplost, teamstr);
                 firstpersondrop = true;
             }
-            else hudoutf("\f2%s %s %s %s flag", flagteam, colorname(act), droplost, teamstr);
+            else hudoutf("\f2%s%s %s %s flag", flagteam, colorname(act), droplost, teamstr);
             break;
         }
         case FA_RETURN:
             audiomgr.playsound(S_FLAGRETURN, SP_HIGHEST);
             if (firstperson) hudoutf("\f2you returned %s flag", teamstr);
-            else hudoutf("\f2%s %s returned %s flag", flagteam, colorname(act), teamstr);
+            else hudoutf("\f2%s%s returned %s flag", flagteam, colorname(act), teamstr);
             break;
         case FA_SCORE:
             audiomgr.playsound(S_FLAGSCORE, SP_HIGHEST);
@@ -1355,7 +1358,7 @@ void flagmsg(int flag, int message, int actor, int flagtime)
             break;
         case FA_RESET:
             audiomgr.playsound(S_FLAGRETURN, SP_HIGHEST);
-            hudoutf("the server reset the flag");
+            hudoutf("the server reset %s flag", teamstr);
             firstpersondrop = true;
             break;
     }
