@@ -357,7 +357,7 @@ void parsemessages(int cn, playerent *d, ucharbuf &p, bool demo = false)
                 if (prot != PROTOCOL_VERSION && !(watchingdemo && prot == -PROTOCOL_VERSION))
                 {
                     conoutf(_("%c3incompatible game protocol (local protocol: %d :: server protocol: %d)"), CC, PROTOCOL_VERSION, prot);
-                    conoutf("\f3if this occurs a lot, obtain an upgrade from \f1http://acr.victorz.ca");
+                    conoutf("\f3if this occurs a lot, obtain an upgrade from \f1https://acr.victorz.ca");
                     if(watchingdemo) conoutf("breaking loop : \f3this demo is using a different protocol\f5 : end it now!"); // SVN-WiP-bug: causes endless retry loop else!
                     else disconnect();
                     return;
@@ -1079,6 +1079,7 @@ void parsemessages(int cn, playerent *d, ucharbuf &p, bool demo = false)
                 const int cn = getint(p), health = getint(p);
                 playerent *d = getclient(cn);
                 if (!d) break;
+                d->adddamage_world(totalmillis, d->health - health, d == focus);
                 d->health = health;
                 d->lastregen = lastmillis;
                 if (!healer) break;
@@ -1754,7 +1755,7 @@ void parsemessages(int cn, playerent *d, ucharbuf &p, bool demo = false)
             {
                 int vres = getint(p), vetocn = getint(p);
                 playerent *d = getclient(vetocn);
-                curvote->veto = (d != NULL);
+                if (curvote) curvote->veto = (d != NULL);
                 if (curvote && vres >= 0 && vres < VOTE_NUM)
                 {
                     curvote->result = vres;
