@@ -315,7 +315,11 @@ void pickupeffects(int n, playerent *d, int spawntime)
     e.spawned = false;
     e.spawntime = lastmillis + spawntime;
     if(!d) return;
+
+    const int oldhealth = d->health;
     d->pickup(e.type);
+    if (d->health != oldhealth) d->adddamage_world(totalmillis, oldhealth - d->health, d == focus);
+
     const itemstat *is = d->itemstats(e.type);
     if(is)
     {
@@ -334,7 +338,6 @@ void pickupeffects(int n, playerent *d, int spawntime)
             */
             if(identexists("onPickup"))
             {
-                string o;
                 itemstat *tmp = NULL;
                 switch(e.type)
                 {
@@ -349,7 +352,7 @@ void pickupeffects(int n, playerent *d, int spawntime)
                 }
                 if(tmp)
                 {
-                    formatstring(o)("onPickup %d %d", e.type - 3, m_lss(gamemode, mutators) && e.type == I_GRENADE ? 2 : tmp->add);
+                    defformatstring(o)("onPickup %d %d", e.type - 3, m_lss(gamemode, mutators) && e.type == I_GRENADE ? 2 : tmp->add);
                     execute(o);
                 }
             }
