@@ -55,12 +55,9 @@ void drawflagicons(int team, playerent *p)
             f.actor == p && f.state == CTFF_STOLEN ? (sinf(totalmillis / 100.0f) + 1.0f) / 2.0f :
             1
             );
-        // CTF
-        int row = 0;
-        // HTF
-        if (m_hunt(gamemode)) row = 1;
-        // KTF
-        else if (m_keep(gamemode)) row = 2;
+        int row = m_capture(gamemode) ? 0 // CTF
+            : m_keep(gamemode) ? 2 // KTF
+            : 1; // HTF or Bomber
         drawicon(flagtex, team * 120 + VIRTW / 4.0f*3.0f, 1650, 120, team, row, 1 / 3.f);
     }
 
@@ -71,7 +68,7 @@ void drawflagicons(int team, playerent *p)
 
     Texture *t = (m_capture(gamemode) || (m_ktf2(gamemode, mutators) && m_team(gamemode, mutators))) ? ctftex : hktftex;
     if (!t) return;
-    // CTF OR KTF2/Returner
+    // CTF (returner) OR KTF2
     int row = (m_capture(gamemode) || (m_ktf2(gamemode, mutators) && m_team(gamemode, mutators))) && f.actor && f.actor->team == team ? 1 : 0;
     // KTF
     if (m_keep(gamemode) && !(m_ktf2(gamemode, mutators) && m_team(gamemode, mutators))) row = 1;
@@ -470,17 +467,18 @@ void draweventicons()
 {
     static Texture **texs = geteventicons();
 
+    const int eventicontime = 3000;
     loopv(focus->icons)
     {
         eventicon &icon = focus->icons[i];
-        if (icon.type < 0 || icon.type >= eventicon::TOTAL || icon.millis + 3000 < totalmillis)
+        if (icon.type < 0 || icon.type >= eventicon::TOTAL || icon.millis + eventicontime < totalmillis)
         {
             focus->icons.remove(i--);
             continue;
         }
         Texture *tex = texs[icon.type];
         int h = 1;
-        float aspect = 1, scalef = 1, offset = (totalmillis - icon.millis) / 3000.f * 160.f;
+        float aspect = 1, scalef = 1, offset = (totalmillis - icon.millis) / (float)eventicontime * 160.f;
         switch (icon.type)
         {
         case eventicon::CHAT:
@@ -506,7 +504,7 @@ void draweventicons()
         glBindTexture(GL_TEXTURE_2D, tex->id);
         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
         glEnable(GL_BLEND);
-        glColor4f(1.f, 1.f, 1.f, (3000 + icon.millis - totalmillis) / 3000.f);
+        glColor4f(1.f, 1.f, 1.f, (eventicontime + icon.millis - totalmillis) / (float)eventicontime);
         glBegin(GL_TRIANGLE_STRIP);
         float anim = (totalmillis / 100) % (h * 2);
         if (anim >= h) anim = h * 2 - anim + 1;
@@ -519,6 +517,28 @@ void draweventicons()
         glTexCoord2f(1, anim); glVertex2f(VIRTW / 2 + xx, VIRTH / 2 + yy + yoffset);
         glEnd();
     }
+
+    const int damagetime = 3000;
+    float prevYoff = 0;
+    loopvrev(focus->damagelist_world)
+    {
+        const damageparticleinfo &d = focus->damagelist_world[i];
+        const int t = totalmillis - d.millis;
+        if (t > damagetime)
+        {
+            focus->damagelist_world.remove(i);
+            continue;
+        }
+
+        glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+        glEnable(GL_BLEND);
+        div_t dmg = div(d.damage, HEALTHSCALE);
+        defformatstring(damagetext)(dmg.rem ? "\f%c%d.%*d" : "\f%c%d", d.color, dmg.quot, HEALTHPRECISION, dmg.rem);
+        const int xoff = d.xoff * 50 - text_width(damagetext) / 2;
+        const float yoff = min(d.yoff * 50 - t * (float)(VIRTH / 3) / damagetime, prevYoff);
+        prevYoff = yoff - FONTH;
+        draw_text(damagetext, VIRTW / 2 + xoff, VIRTH / 2 + yoff, 255, 255, 255, 255 * min(damagetime - t, damagetime) / (float)damagetime);
+    }
 }
 
 VARP(hidedamageindicator, 0, 0, 1);
@@ -529,7 +549,7 @@ VARP(damageindicatoralpha, 1, 50, 100);
 
 void drawdmgindicator()
 {
-    if (!damageindicatorsize || !focus->damagestack.length()) return;
+    if (!damageindicatorsize || !focus->damagelist_hud.length()) return;
 
     static Texture *damagedirtex = NULL;
     if (!damagedirtex) damagedirtex = textureload("packages/misc/damagedir.png", 3);
@@ -537,13 +557,13 @@ void drawdmgindicator()
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     glBindTexture(GL_TEXTURE_2D, damagedirtex->id);
 
-    loopv(focus->damagestack)
+    loopv(focus->damagelist_hud)
     {
-        const damageinfo &pain = focus->damagestack[i];
+        const damageinfo &pain = focus->damagelist_hud[i];
         const float damagefade = damageindicatortime + pain.damage * 200 / HEALTHSCALE;
         if (pain.millis + damagefade <= totalmillis)
         {
-            focus->damagestack.remove(i--);
+            focus->damagelist_hud.remove(i--);
             continue;
         }
         vec dir = pain.o;
@@ -745,7 +765,7 @@ vec getradarpos()
 
 void DrawCircle(float cx, float cy, float r, GLubyte *col, float thickness = 1.f, int segments = 720)
 {
-    // Adapted from public domain code at http://slabode.exofire.net/circle_draw.shtml
+    // Adapted from public domain code at https://slabode.exofire.net/circle_draw.shtml
     const float theta = 2 * PI / float(segments);
     const float c = cosf(theta); // precalculate the sine and cosine
     const float s = sinf(theta);
