@@ -254,7 +254,7 @@ int connectwithtimeout(ENetSocket sock, const char *hostname, ENetAddress &addre
     connectdata cd = { sock, address, -1 };
     connthread = SDL_CreateThread(connectthread, &cd);
 
-    int starttime = SDL_GetTicks(), timeout = 0;
+    int starttime = SDL_GetTicks();
     for(;;)
     {
         if(!SDL_CondWaitTimeout(conncond, connmutex, 250))
@@ -262,7 +262,7 @@ int connectwithtimeout(ENetSocket sock, const char *hostname, ENetAddress &addre
             if(cd.result<0) enet_socket_destroy(sock);
             break;
         }
-        timeout = SDL_GetTicks() - starttime;
+        int timeout = SDL_GetTicks() - starttime;
         show_out_of_renderloop_progress(min(float(timeout)/CONNLIMIT, 1.0f), text);
         SDL_Event event;
         while(SDL_PollEvent(&event))
@@ -567,15 +567,17 @@ void checkpings()
                     case EXTPING_UPLINKSTATS:
                     {
                         si->uplinkqual_age = totalmillis;
-                        //if(si->maxclients > 3)
+                        if(si->maxclients > 3)
                         {
-                            int maxs = 0, maxc = 0, ts, tc;
+                            int ignore = (si->maxclients < 8 ? 3 : 6) - 1;
+                            int maxs = 0, maxc = 0;
                             loopi(min(si->maxclients, MAXCLIENTS))
                             {
-                                ts = tc = si->uplinkstats[i] = p.get();
-                                if(si->maxclients < 8 || i > 2)
+                                si->uplinkstats[i] = p.get();
+                                if(i > ignore)
                                 {
-                                    ts &= 0xF0; tc &= 0x0F;
+                                    int ts = si->uplinkstats[i] & 0xF0;
+                                    int tc = si->uplinkstats[i] & 0x0F;
                                     if(ts > maxs) maxs = ts;
                                     if(ts > 0x40 && tc > maxc) maxc = tc;   // spent time = 2 ^ ((ts >> 4) - 1) * 30 sec, so 0x50 is 8..15 minutes
                                 }
@@ -673,6 +675,8 @@ void serversortprepare()
     {
         serverinfo &si = *servers[i];
         // basic group weights: used(700) - empty(500) - usable(200) - unusable(100)
+        // used: +100 with official map
+        // any:  -50 if bypassing master-server policy
         if(si.protocol != PROTOCOL_VERSION) si.weight += (si.protocol == -PROTOCOL_VERSION ? 200 : 100);
         else if(!si.numplayers) si.weight += 500;
         else
@@ -680,6 +684,7 @@ void serversortprepare()
             si.weight += 700;
             if(serversortpreferofficial && securemapcheck(si.map, false)) si.weight += 100;
         }
+        if(si.pongflags & ((1 << PONGFLAG_BYPASSBANS) | (1 << PONGFLAG_BYPASSPRIV))) si.weight -= 50;
         si.weight += si.msweight;
     }
 }
@@ -811,7 +816,7 @@ void addfavcategory(const char *refdes)
     loopi(FC_NUM) alx[i] = getalias(favcatargname(text, i)) ? 1 : 0;
     loopi(3)
     {
-        formatstring(val)("%d", *text & (1 << i) ? 90 : 10);
+        formatstring(val)("%d", (*text & (1 << i)) ? 90 : 10);
         if(!alx[i + FC_RED]) alias(favcatargname(text, i + FC_RED), val);
     }
     formatstring(val)("favourites %d", favcats.length());
@@ -1330,7 +1335,7 @@ static size_t write_callback(void *ptr, size_t size, size_t nmemb, FILE *stream)
 void retrieveservers(vector<char> &data)
 {
     string request;
-    sprintf(request, "http://%s:%u%s/c?build_defs=%d&guid32=%lu", masterbase, masterport, masterpath, getbuildtype(), *&genguid(234534, 546456456U, 345345453, "3458739874jetrgjk"));
+    sprintf(request, "http://%s:%d%s/c?build_defs=%d&guid32=%lu", masterbase, masterport, masterpath, getbuildtype(), *&genguid(234534, 546456456U, 345345453, "3458739874jetrgjk"));
 
     const char *tmpname = findfile(path("config/servers.cfg", true), "wb");
     FILE *outfile = fopen(tmpname, "w+");
@@ -1361,8 +1366,7 @@ void retrieveservers(vector<char> &data)
     result = curl_easy_perform(curl);
     curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &httpresult);
     curl_easy_cleanup(curl);
-    curl = NULL;
-    if(outfile) fclose(outfile);
+    fclose(outfile);
 
     if(!result && httpresult == 200)
     {
@@ -1387,7 +1391,7 @@ void updatefrommaster(int force)
 
     if(data.empty())
     {
-        conoutf("Master server is not replying. \f1Get more information at http://ms.acr.victorz.ca/bans");
+        conoutf("Master server is not replying. \f1Get more information at https://acrms.victorz.ca/bans");
     }
     else
     {
